==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/IntegrationRuntimeComputePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The compute resource properties for managed integration runtime.
 * @property copyComputeScaleProperties CopyComputeScale properties for managed integration runtime.
 * @property dataFlowProperties Data flow properties for managed integration runtime.
 * @property location The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
 * @property maxParallelExecutionsPerNode Maximum parallel executions count per node for managed integration runtime.
 * @property nodeSize The node size requirement to managed integration runtime.
 * @property numberOfNodes The required number of nodes for managed integration runtime.
 * @property pipelineExternalComputeScaleProperties PipelineExternalComputeScale properties for managed integration runtime.
 * @property vNetProperties VNet properties for managed integration runtime.
 */
public data class IntegrationRuntimeComputePropertiesArgs(
    public val copyComputeScaleProperties: Output<CopyComputeScalePropertiesArgs>? = null,
    public val dataFlowProperties: Output<IntegrationRuntimeDataFlowPropertiesArgs>? = null,
    public val location: Output<String>? = null,
    public val maxParallelExecutionsPerNode: Output<Int>? = null,
    public val nodeSize: Output<String>? = null,
    public val numberOfNodes: Output<Int>? = null,
    public val pipelineExternalComputeScaleProperties:
    Output<PipelineExternalComputeScalePropertiesArgs>? = null,
    public val vNetProperties: Output<IntegrationRuntimeVNetPropertiesArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs =
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs.builder()
            .copyComputeScaleProperties(
                copyComputeScaleProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dataFlowProperties(
                dataFlowProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .location(location?.applyValue({ args0 -> args0 }))
            .maxParallelExecutionsPerNode(maxParallelExecutionsPerNode?.applyValue({ args0 -> args0 }))
            .nodeSize(nodeSize?.applyValue({ args0 -> args0 }))
            .numberOfNodes(numberOfNodes?.applyValue({ args0 -> args0 }))
            .pipelineExternalComputeScaleProperties(
                pipelineExternalComputeScaleProperties?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .vNetProperties(
                vNetProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationRuntimeComputePropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeComputePropertiesArgsBuilder internal constructor() {
    private var copyComputeScaleProperties: Output<CopyComputeScalePropertiesArgs>? = null

    private var dataFlowProperties: Output<IntegrationRuntimeDataFlowPropertiesArgs>? = null

    private var location: Output<String>? = null

    private var maxParallelExecutionsPerNode: Output<Int>? = null

    private var nodeSize: Output<String>? = null

    private var numberOfNodes: Output<Int>? = null

    private var pipelineExternalComputeScaleProperties:
        Output<PipelineExternalComputeScalePropertiesArgs>? = null

    private var vNetProperties: Output<IntegrationRuntimeVNetPropertiesArgs>? = null

    /**
     * @param value CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("fmdcbhkkecgsgqps")
    public suspend fun copyComputeScaleProperties(`value`: Output<CopyComputeScalePropertiesArgs>) {
        this.copyComputeScaleProperties = value
    }

    /**
     * @param value Data flow properties for managed integration runtime.
     */
    @JvmName("jvysbfhwsxekvknh")
    public suspend fun dataFlowProperties(`value`: Output<IntegrationRuntimeDataFlowPropertiesArgs>) {
        this.dataFlowProperties = value
    }

    /**
     * @param value The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
     */
    @JvmName("iosxdivgckvgtoid")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Maximum parallel executions count per node for managed integration runtime.
     */
    @JvmName("tmapfuoaubkvdoyc")
    public suspend fun maxParallelExecutionsPerNode(`value`: Output<Int>) {
        this.maxParallelExecutionsPerNode = value
    }

    /**
     * @param value The node size requirement to managed integration runtime.
     */
    @JvmName("drdynffxqyehaqfs")
    public suspend fun nodeSize(`value`: Output<String>) {
        this.nodeSize = value
    }

    /**
     * @param value The required number of nodes for managed integration runtime.
     */
    @JvmName("bbeihenoceuoitnl")
    public suspend fun numberOfNodes(`value`: Output<Int>) {
        this.numberOfNodes = value
    }

    /**
     * @param value PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("oqkcusangfbwawwv")
    public suspend
    fun pipelineExternalComputeScaleProperties(`value`: Output<PipelineExternalComputeScalePropertiesArgs>) {
        this.pipelineExternalComputeScaleProperties = value
    }

    /**
     * @param value VNet properties for managed integration runtime.
     */
    @JvmName("aofcajfgypixuxip")
    public suspend fun vNetProperties(`value`: Output<IntegrationRuntimeVNetPropertiesArgs>) {
        this.vNetProperties = value
    }

    /**
     * @param value CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("ojdxvpkvtihqahin")
    public suspend fun copyComputeScaleProperties(`value`: CopyComputeScalePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.copyComputeScaleProperties = mapped
    }

    /**
     * @param argument CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("vagarmqpaypxfgcs")
    public suspend
    fun copyComputeScaleProperties(argument: suspend CopyComputeScalePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = CopyComputeScalePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.copyComputeScaleProperties = mapped
    }

    /**
     * @param value Data flow properties for managed integration runtime.
     */
    @JvmName("ydiroywdwumcwjfp")
    public suspend fun dataFlowProperties(`value`: IntegrationRuntimeDataFlowPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataFlowProperties = mapped
    }

    /**
     * @param argument Data flow properties for managed integration runtime.
     */
    @JvmName("pxptgrtfwpisusti")
    public suspend
    fun dataFlowProperties(argument: suspend IntegrationRuntimeDataFlowPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeDataFlowPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dataFlowProperties = mapped
    }

    /**
     * @param value The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
     */
    @JvmName("sifvjcxjxrabryrd")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Maximum parallel executions count per node for managed integration runtime.
     */
    @JvmName("rvpmfpkknriexhwt")
    public suspend fun maxParallelExecutionsPerNode(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxParallelExecutionsPerNode = mapped
    }

    /**
     * @param value The node size requirement to managed integration runtime.
     */
    @JvmName("gixteircjmhbjydn")
    public suspend fun nodeSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nodeSize = mapped
    }

    /**
     * @param value The required number of nodes for managed integration runtime.
     */
    @JvmName("dreyyrwgdnghaxik")
    public suspend fun numberOfNodes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.numberOfNodes = mapped
    }

    /**
     * @param value PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("ekjkfxcnvtumiqqj")
    public suspend
    fun pipelineExternalComputeScaleProperties(`value`: PipelineExternalComputeScalePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pipelineExternalComputeScaleProperties = mapped
    }

    /**
     * @param argument PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("uhytldqkvcgrlrda")
    public suspend
    fun pipelineExternalComputeScaleProperties(argument: suspend PipelineExternalComputeScalePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PipelineExternalComputeScalePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.pipelineExternalComputeScaleProperties = mapped
    }

    /**
     * @param value VNet properties for managed integration runtime.
     */
    @JvmName("urvwgtprabgsadkg")
    public suspend fun vNetProperties(`value`: IntegrationRuntimeVNetPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vNetProperties = mapped
    }

    /**
     * @param argument VNet properties for managed integration runtime.
     */
    @JvmName("qdydbppaqohvdijf")
    public suspend
    fun vNetProperties(argument: suspend IntegrationRuntimeVNetPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeVNetPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.vNetProperties = mapped
    }

    internal fun build(): IntegrationRuntimeComputePropertiesArgs =
        IntegrationRuntimeComputePropertiesArgs(
            copyComputeScaleProperties = copyComputeScaleProperties,
            dataFlowProperties = dataFlowProperties,
            location = location,
            maxParallelExecutionsPerNode = maxParallelExecutionsPerNode,
            nodeSize = nodeSize,
            numberOfNodes = numberOfNodes,
            pipelineExternalComputeScaleProperties = pipelineExternalComputeScaleProperties,
            vNetProperties = vNetProperties,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/IntegrationRuntimeComputePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The compute resource properties for managed integration runtime.
 * @property copyComputeScaleProperties CopyComputeScale properties for managed integration runtime.
 * @property dataFlowProperties Data flow properties for managed integration runtime.
 * @property location The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
 * @property maxParallelExecutionsPerNode Maximum parallel executions count per node for managed integration runtime.
 * @property nodeSize The node size requirement to managed integration runtime.
 * @property numberOfNodes The required number of nodes for managed integration runtime.
 * @property pipelineExternalComputeScaleProperties PipelineExternalComputeScale properties for managed integration runtime.
 * @property vNetProperties VNet properties for managed integration runtime.
 */
public data class IntegrationRuntimeComputePropertiesArgs(
    public val copyComputeScaleProperties: Output<CopyComputeScalePropertiesArgs>? = null,
    public val dataFlowProperties: Output<IntegrationRuntimeDataFlowPropertiesArgs>? = null,
    public val location: Output<String>? = null,
    public val maxParallelExecutionsPerNode: Output<Int>? = null,
    public val nodeSize: Output<String>? = null,
    public val numberOfNodes: Output<Int>? = null,
    public val pipelineExternalComputeScaleProperties:
    Output<PipelineExternalComputeScalePropertiesArgs>? = null,
    public val vNetProperties: Output<IntegrationRuntimeVNetPropertiesArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs =
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeComputePropertiesArgs.builder()
            .copyComputeScaleProperties(
                copyComputeScaleProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dataFlowProperties(
                dataFlowProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .location(location?.applyValue({ args0 -> args0 }))
            .maxParallelExecutionsPerNode(maxParallelExecutionsPerNode?.applyValue({ args0 -> args0 }))
            .nodeSize(nodeSize?.applyValue({ args0 -> args0 }))
            .numberOfNodes(numberOfNodes?.applyValue({ args0 -> args0 }))
            .pipelineExternalComputeScaleProperties(
                pipelineExternalComputeScaleProperties?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .vNetProperties(
                vNetProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationRuntimeComputePropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeComputePropertiesArgsBuilder internal constructor() {
    private var copyComputeScaleProperties: Output<CopyComputeScalePropertiesArgs>? = null

    private var dataFlowProperties: Output<IntegrationRuntimeDataFlowPropertiesArgs>? = null

    private var location: Output<String>? = null

    private var maxParallelExecutionsPerNode: Output<Int>? = null

    private var nodeSize: Output<String>? = null

    private var numberOfNodes: Output<Int>? = null

    private var pipelineExternalComputeScaleProperties:
        Output<PipelineExternalComputeScalePropertiesArgs>? = null

    private var vNetProperties: Output<IntegrationRuntimeVNetPropertiesArgs>? = null

    /**
     * @param value CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("ofibnuuhhiafprsd")
    public suspend fun copyComputeScaleProperties(`value`: Output<CopyComputeScalePropertiesArgs>) {
        this.copyComputeScaleProperties = value
    }

    /**
     * @param value Data flow properties for managed integration runtime.
     */
    @JvmName("tttreipoehhdnhgv")
    public suspend fun dataFlowProperties(`value`: Output<IntegrationRuntimeDataFlowPropertiesArgs>) {
        this.dataFlowProperties = value
    }

    /**
     * @param value The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
     */
    @JvmName("jojdorabvymkgodh")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Maximum parallel executions count per node for managed integration runtime.
     */
    @JvmName("ebcwiwibckdsjajo")
    public suspend fun maxParallelExecutionsPerNode(`value`: Output<Int>) {
        this.maxParallelExecutionsPerNode = value
    }

    /**
     * @param value The node size requirement to managed integration runtime.
     */
    @JvmName("uddfwclkpxdrrkcq")
    public suspend fun nodeSize(`value`: Output<String>) {
        this.nodeSize = value
    }

    /**
     * @param value The required number of nodes for managed integration runtime.
     */
    @JvmName("kbuujxqqcvffffar")
    public suspend fun numberOfNodes(`value`: Output<Int>) {
        this.numberOfNodes = value
    }

    /**
     * @param value PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("rfvscenkcbbcknro")
    public suspend
    fun pipelineExternalComputeScaleProperties(`value`: Output<PipelineExternalComputeScalePropertiesArgs>) {
        this.pipelineExternalComputeScaleProperties = value
    }

    /**
     * @param value VNet properties for managed integration runtime.
     */
    @JvmName("sdkjmfadrdhubpbh")
    public suspend fun vNetProperties(`value`: Output<IntegrationRuntimeVNetPropertiesArgs>) {
        this.vNetProperties = value
    }

    /**
     * @param value CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("almucabyasmyerwl")
    public suspend fun copyComputeScaleProperties(`value`: CopyComputeScalePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.copyComputeScaleProperties = mapped
    }

    /**
     * @param argument CopyComputeScale properties for managed integration runtime.
     */
    @JvmName("kijphugbiwgsqtto")
    public suspend
    fun copyComputeScaleProperties(argument: suspend CopyComputeScalePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = CopyComputeScalePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.copyComputeScaleProperties = mapped
    }

    /**
     * @param value Data flow properties for managed integration runtime.
     */
    @JvmName("gbstmuxttbrxaynu")
    public suspend fun dataFlowProperties(`value`: IntegrationRuntimeDataFlowPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataFlowProperties = mapped
    }

    /**
     * @param argument Data flow properties for managed integration runtime.
     */
    @JvmName("bcymiustosgkhxco")
    public suspend
    fun dataFlowProperties(argument: suspend IntegrationRuntimeDataFlowPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeDataFlowPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dataFlowProperties = mapped
    }

    /**
     * @param value The location for managed integration runtime. The supported regions could be found on https://docs.microsoft.com/en-us/azure/data-factory/data-factory-data-movement-activities
     */
    @JvmName("bbnxmyckjxasgsyj")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Maximum parallel executions count per node for managed integration runtime.
     */
    @JvmName("sxrnrjvjitvbxnsq")
    public suspend fun maxParallelExecutionsPerNode(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxParallelExecutionsPerNode = mapped
    }

    /**
     * @param value The node size requirement to managed integration runtime.
     */
    @JvmName("mvaeuiutggvgvthw")
    public suspend fun nodeSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nodeSize = mapped
    }

    /**
     * @param value The required number of nodes for managed integration runtime.
     */
    @JvmName("xxinlawjpcnukfuv")
    public suspend fun numberOfNodes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.numberOfNodes = mapped
    }

    /**
     * @param value PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("noqlcgfkvphirqgl")
    public suspend
    fun pipelineExternalComputeScaleProperties(`value`: PipelineExternalComputeScalePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pipelineExternalComputeScaleProperties = mapped
    }

    /**
     * @param argument PipelineExternalComputeScale properties for managed integration runtime.
     */
    @JvmName("alnkjpjvwlbtchna")
    public suspend
    fun pipelineExternalComputeScaleProperties(argument: suspend PipelineExternalComputeScalePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PipelineExternalComputeScalePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.pipelineExternalComputeScaleProperties = mapped
    }

    /**
     * @param value VNet properties for managed integration runtime.
     */
    @JvmName("mblcgmsyqeuqcfcq")
    public suspend fun vNetProperties(`value`: IntegrationRuntimeVNetPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vNetProperties = mapped
    }

    /**
     * @param argument VNet properties for managed integration runtime.
     */
    @JvmName("jcwcumpdtibhgsxt")
    public suspend
    fun vNetProperties(argument: suspend IntegrationRuntimeVNetPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeVNetPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.vNetProperties = mapped
    }

    internal fun build(): IntegrationRuntimeComputePropertiesArgs =
        IntegrationRuntimeComputePropertiesArgs(
            copyComputeScaleProperties = copyComputeScaleProperties,
            dataFlowProperties = dataFlowProperties,
            location = location,
            maxParallelExecutionsPerNode = maxParallelExecutionsPerNode,
            nodeSize = nodeSize,
            numberOfNodes = numberOfNodes,
            pipelineExternalComputeScaleProperties = pipelineExternalComputeScaleProperties,
            vNetProperties = vNetProperties,
        )
}
